#include <VRS51L3074_SDCC.h>

#include "SHTxx.h"
#include "SHTxx_highlevel.h"

#include <math.h>  
#include <stdio.h>

typedef union {
  unsigned int i;
  float f;
} value;

//;-------------------------------------------------------------------
//;- DELAY1MSTO : 1MS DELAY USING TIMER0
//; CALIBRATED FOR 40MHZ
//;-------------------------------------------------------------------
void delay(unsigned int dlais){
idata unsigned char x=0;
idata unsigned int dlaisloop;
x = PERIPHEN1; //LOAD PERIPHEN1 REG
x |= 0x01; //ENABLE TIMER 0
PERIPHEN1 = x;
dlaisloop = dlais;
while ( dlaisloop > 0)
{
TH0 = 0x63; //TIMER0 RELOAD VALUE FOR 1MS AT 40MHZ
TL0 = 0xC0;
T0T1CLKCFG = 0x00; //NO PRESCALER FOR TIMER 0 CLOCK
T0CON = 0x04; //START TIMER 0, COUNT UP
do{
x=T0CON;
x= x & 0x80;
}while(x==0);
T0CON = 0x00; //Stop Timer 0
dlaisloop = dlaisloop-1;
}//end of while dlais...
x = PERIPHEN1; //LOAD PERIPHEN1 REG
x = x & 0xFE; //DISABLEBLE TIMER 0
PERIPHEN1 = x;
}//End of function delais

#define MsDelay(a) delay(a)

//----------------------------------------------------------------------------------
void main()
//----------------------------------------------------------------------------------
// sample program that shows how to use SHT11 functions
// 1. connection reset 
// 2. measure humidity [ticks](12 bit) and temperature [ticks](14 bit)
// 3. calculate humidity [%RH] and temperature [C]
// 4. calculate dew point [C]
// 5. print temperature, humidity, dew point  

{ 
value humi_val,temp_val;
float dew_point;
unsigned char error,checksum;


  P6PINCFG&=~(1<<6);                        // CLK = output (P6.6)
  s_connectionreset();
  while(1)
  {
    if(!(error=s_measure_start(TEMP))) {  //measure temperature
      while(s_measure_get((unsigned char*) &temp_val.i,&checksum)); // NEEDS TIMEOUT HANDLING
      if(!(error=s_measure_start(HUMI))) {  //measure humidity
	while(s_measure_get((unsigned char*) &humi_val.i,&checksum)); // DITTO
      }
    }
    if(error)
      s_connectionreset();                 // in case of an error: connection reset
    else {
      humi_val.f=(float)humi_val.i;                   //converts integer to float
      temp_val.f=(float)temp_val.i;                   //converts integer to float
      calc_sth11(&humi_val.f,&temp_val.f);            //calculate humidity, temperature
      dew_point=calc_dewpoint(humi_val.f,temp_val.f); //calculate dew point
    }
    MsDelay(1000);//----------wait approx. 0.8s to avoid heating up SHTxx------------------------------      
  }
} 
